from dataclasses import dataclass

from sarina.providers import Domain, Server


@dataclass
class Template:
    type: str
    description = ""

    def provision_server(self, server: Server):
        raise NotImplemented()

    def generate_key(self, domain: Domain):
        raise NotImplemented()


script_install_docker = """
which docker > /dev/null || (
    umask 0022
    curl -s https://get.docker.com/ | sh
)
"""

script_install_docker_compose = """
which docker-compose > /dev/null || (
    wget -O /usr/bin/docker-compose https://github.com/docker/compose/releases/download/v2.12.2/docker-compose-linux-x86_64
    chmod +x /usr/bin/docker-compose
)
"""

# Self-signed tls certificate
tls_crt = """
-----BEGIN CERTIFICATE-----
MIIElDCCAnwCCQDlCwAerg6zUzANBgkqhkiG9w0BAQsFADAMMQowCAYDVQQDDAEq
MB4XDTIyMTAzMTAyMDAxMloXDTI1MDcyNzAyMDAxMlowDDEKMAgGA1UEAwwBKjCC
AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAOV0rN2wcoWuwHtvYyjKO3NL
WQSCB1u/bDrJYXEFCjCaQFuEVWjW44vHwBnTanWPt2TcEN8ZZ7Nd3fku8ZN7I7i9
3CPRUDatBD/IE6s90JY0dR8i4ZavOorTD8D8Xg5ioh9KdyEnEmgZpDjzENBEJQZa
jUMytEwM5BJYO1QY6TInRbC0XCigouPBdhHR88kc5e/+tAqY7UC5x48CkLIcDAxQ
IzPBdGWheSPjLYLn6XM0QkatZK6/7q40f03BMt29AVvwN3XgU9xBwr4Iij5nC3AV
RfwBbySx+d+5rIxfsm6L5xOP0Zm5IueWNyCa8JDYrxdOf35bcm9VdPvay0IDp4Dr
gTqWRvLWzBCmsXKdOIDo3O0W3UcSfzjyiue+VKNJFOFEpS02RfqaQZ4k+YpS1QIz
3CyzDb7GVq4gNTO7P4hcMXvWxJPqoA6QYAeboHMQr695ucdjF4hebbVMNajXndhf
BPmvAGKZivUn/PZND1vTj331mqWUMQTJOyvUVv+ZpEobhr3GQvScbFw5zLOaR5ud
LAxgmtcyspCC4MQhu7bNPtnP5jhBXmdiNf7bbUQFgnaGDrNKELMIUeY3/TLAs6cv
U+ZbrbofL3eGMZtCeH/7izZxX2cS1OxcHNesqOU7+ZLznbu7AXGrDo6lH/4VbC44
YaKbn4oxfplUpQcmWWvJAgMBAAEwDQYJKoZIhvcNAQELBQADggIBABdLOenVrN4/
D2NZJiD027LVcxnWTEjCCMgoaZ1eeQdaHlpQueL1hpZDTnFCZEsbnp77GFqXhNt4
lnUgF4n8JmFoqR39MCu76k7VlndLTG2aMPOrc6zfe2JUeaC4Q6/BwothMu1xuz6P
kbWResrXVIbdVH+NPqN3SFzye8MQzBkNcgiNRY9syzaPXUD3OfOYT6xnUU6orqsX
LWnCuakRK9YlaK9X6BdPen12wyAbKg+M4eUMTnC/VTRFjHz8H8CnYjk/bzoxUQZG
QV9XK+2dw0A0MLNXiWtoUmemS/ty+tSMnvEMdfXyskJcP3qVbywp4G4E1cUiHw9z
e+0xYZQnaX0I6ztZWliK8ELHEucS+M20VODVUEryKl/zpqq7Rpx16T4VRrnqtYj2
MqGLWhjUvDRFsuDaVCTbP8oZS3CrR6p0pfHqatYXcRY8E1YeMaGBMz5DKpgEhbjo
2x6md9E7LWVRa4FQu0N/V5xlTUSGUzzgLAXIXhLiKT0B+FutG914zN8z6AOQ7DMY
IhhosVG535/mL8AnPAoDorOSz5Vk1OxPWYCLFiUZK8rqcP3+z0xe4S/bsoGaz7Oc
J/LzGxaanEKi53lS3zg/N4QYWmWe++l59fZVPa0HiAPsMCoHnOGPuhnULzGeGuPJ
+bLSo9WYo8HwVFk6RHeKkJcDoYRQIyO+
-----END CERTIFICATE-----""".strip()

tls_key = """-----BEGIN PRIVATE KEY-----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-----END PRIVATE KEY-----""".strip()
